@@ -9,7 +9,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.1800';
+our $VERSION = '0.1900';
 
 1;
 
@@ -25,7 +25,7 @@ Task::MusicBundle - A bundle of MIDI and music modules
 
 =head1 VERSION
 
-version 0.1800
+version 0.1900
 
 =head1 SYNOPSIS
 
@@ -61,15 +61,17 @@ L<Guitar::Scale>
 
 L<MIDI>
 
+L<MIDI::Chord::Guitar>
+
 L<MIDI::Drummer::Tiny>
 
-L<MIDI::Morph> - Jun 04, 2005
+L<MIDI::Morph>
 
 L<MIDI::Ngram>
 
-L<MIDI::Pitch> - Nov 30, 2005
+L<MIDI::Pitch>
 
-L<MIDI::Praxis::Variation> - Sept 30, 2005
+L<MIDI::Praxis::Variation>
 
 L<MIDI::Simple::Drummer>
 
@@ -77,9 +79,9 @@ L<MIDI::SoundFont>
 
 L<MIDI::Tab>
 
-L<MIDI::Tools> - Jun 04, 2005
+L<MIDI::Tools>
 
-L<MIDI::Trans> - May 24, 2002
+L<MIDI::Trans>
 
 L<MIDI::Tweaks>
 
@@ -93,7 +95,7 @@ L<Music::Canon>
 
 L<Music::ChordBot>
 
-L<Music::Chord::Namer> - Mar 14, 2006
+L<Music::Chord::Namer>
 
 L<Music::Chord::Note>
 
@@ -101,9 +103,11 @@ L<Music::Chord::Positions>
 
 L<Music::Duration>
 
-L<Music::Gestalt> - Jul 13, 2005
+L<Music::Duration::Partition>
 
-L<Music::Harmonics> - May 11, 2005
+L<Music::Gestalt>
+
+L<Music::Harmonics>
 
 L<Music::Interval::Barycentric>
 
@@ -125,9 +129,9 @@ L<Music::Scala>
 
 L<Music::ScaleNote>
 
-L<Music::Scales> - Aug 08, 2003
+L<Music::Scales>
 
-L<Music::Tempo> - Aug 08, 2003
+L<Music::Tempo>
 
 L<Music::Tension>
 
@@ -145,7 +149,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Gene Boggs.
+This software is copyright (c) 2020 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
